"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RNGestureHandler = RNGestureHandler;
exports.getDefaultTapRNGesture = exports.getDefaultRNGestures = exports.getDefaultPinchRNGesture = exports.getDefaultPanRNGesture = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _styles = require("./styles");
var _throttle = require("../utils/throttle");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const getDefaultPanRNGesture = (Gesture, dispatchEvents) => {
  return Gesture.Pan().runOnJS(true).maxPointers(1).onBegin(e => {
    dispatchEvents(['mousedown', 'mousemove'], e);
  }).onUpdate((0, _throttle.throttle)(e => {
    dispatchEvents(['mousemove'], e);
  }, 50)).onEnd(e => {
    dispatchEvents(['mouseup'], e);
  });
};
exports.getDefaultPanRNGesture = getDefaultPanRNGesture;
const getDefaultPinchRNGesture = (Gesture, dispatchEvents) => {
  return Gesture.Pinch().runOnJS(true).onUpdate((0, _throttle.throttle)(e => {
    dispatchEvents(['mousewheel'], e, {
      zrX: e.focalX,
      zrY: e.focalY,
      zrDelta: e.velocity / 20
    });
  }, 50));
};
exports.getDefaultPinchRNGesture = getDefaultPinchRNGesture;
const getDefaultTapRNGesture = (Gesture, dispatchEvents) => {
  return Gesture.Tap().runOnJS(true).onStart(e => {
    dispatchEvents(['mousedown', 'mousemove'], e);
  }).onEnd(e => {
    dispatchEvents(['mouseup', 'click'], e);
  });
};
exports.getDefaultTapRNGesture = getDefaultTapRNGesture;
const getDefaultRNGestures = (Gesture, dispatchEvents) => {
  return [getDefaultPanRNGesture(Gesture, dispatchEvents), getDefaultPinchRNGesture(Gesture, dispatchEvents), getDefaultTapRNGesture(Gesture, dispatchEvents)];
};
exports.getDefaultRNGestures = getDefaultRNGestures;
function RNGestureHandler(_ref) {
  let {
    RNGH,
    dispatchEvents,
    gesture: gestureProp
  } = _ref;
  const {
    Gesture,
    GestureDetector
  } = RNGH;
  const defaultGestures = (0, _react.useMemo)(() => getDefaultRNGestures(Gesture, dispatchEvents), [dispatchEvents, Gesture]);
  const propGesture = (0, _react.useMemo)(() => {
    if (!gestureProp) {
      return defaultGestures;
    }
    if (typeof gestureProp === 'function') {
      return gestureProp(defaultGestures, dispatchEvents);
    }
    return gestureProp;
  }, [defaultGestures, dispatchEvents, gestureProp]);
  const gesture = (0, _react.useMemo)(() => {
    if (Array.isArray(propGesture)) {
      return Gesture.Race(...propGesture);
    }
    return propGesture;
  }, [Gesture, propGesture]);
  return /*#__PURE__*/_react.default.createElement(GestureDetector, {
    gesture: gesture
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _styles.styles.GestureView
  }));
}
//# sourceMappingURL=RNGestureHandler.js.map